<?php
namespace Creativeawesomestep;

use Creativeawesomestep\PageSettings\Page_Settings;
define( "BWDAS_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDAS_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

class ClassBWDASstep {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdas_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdas_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdas_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdas_the_step_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdas-step.php' );
	}

	public function bwdas_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDASAwesomeStep() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdas-awesome-step-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdas_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdas-awesome-step-category',
			[
				'title' => esc_html__( 'BWD Awesome Step', 'bwd-awesome-step' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdas_all_assets_for_the_public(){
		wp_enqueue_style('fontAwesome-css', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.7.0/css/all.min.css', array(), '5.7.0', 'all');
		wp_enqueue_style('bootstrap', 'https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.2.0/css/bootstrap.min.css', array(), '5.2.0', 'all');
		$all_css_js_file = array(
            'bwdas_step_style_css' => array('bwdas_path_define'=>BWDAS_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css'),

        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdas_path_define'], null, '1.0', 'all');
        }
	}
	public function bwdas_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdas_awesome_step_admin_icon_css' => array('bwdas_path_admin_define'=>BWDAS_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdas_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdas_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdas_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdas_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdas_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdas_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
ClassBWDASstep::instance();